/**
 * <p>File: DifferentiableFunction.java</p>
 * <p>Title: Numerical methods</p>
 * <p>Description: Course on numerical analysis</p>
 * <p>Date: January 2016</p>
 * @author Faton M. Berisha
 * @version 6.0.0
 */

package numeric;

import java.util.Observable;

/** 
 * Specifies an interface for a system of equations solver.
 */
public abstract class AbstractSystemSolver extends Observable {

//	private static final long serialVersionUID = 2;

	protected Matrix solution;
	private double tolerance = 1E-8;
	private int numIterations = 50;
	private boolean demo = false;

	/**
	 * Initialises an abstract system solver in <code>n</code> unknowns.
	 * @param n - the number of unknowns
	 */
	public AbstractSystemSolver(int n) {
		solution = new Matrix(n, 1);
	}

	/**
	 * Gets the number of variables.
	 * @return number of variables
	 */
	public abstract int getNumVariables();

	/**
	 * Gets the number of equations.
	 * @return number of equations
	 */
	public abstract int getNumEquations();

	/**
	 * Sets this solver's solution approximating tolerance.
	 * @param tolerance - solution approximating tolerance
	 */
	public void setTolerance(double tolerance) {
		this.tolerance = tolerance;
	}

	/**
	 * Gets this solver's solution approximating tolerance.
	 * @return solution approximating tolerance
	 */
	public double getTolerance() {
		return tolerance;
	}

	/**
	 * Sets the maximum number of iterations for this solver's iterative methods.
	 * @param tolerance - specifies the maximum number of iterations
	 */
	public void setNumIterations(int num) {
		numIterations = num;
	}

	/**
	 * Gets the maximum number of iterations for this solver's iterative methods.
	 * @return the maximum number of iterations
	 */
	public int getNumIterations() {
		return numIterations;
	}

	/**
	 * Gets if the mode is demo.
	 * @return true if the mode is demo, false otherwise
	 */
	public boolean isDemo() {
		return demo;
	}

	/** Sets if the mode is demo.
	 * @param demo - specifies if the mode is demo
	 */
	public void setDemo(boolean demo) {
		this.demo = demo;
	}

	/**
	 * Gets the precalculated solution.
	 * @return <code>Matrix</code> containing the precalculated solution
	 */
	public Matrix getSolution() {
		return solution;
	}

}
