/**
 * <p>File: DifferentiableFunction.java</p>
 * <p>Title: Numerical methods</p>
 * <p>Description: Course on numerical analysis</p>
 * <p>Date: January 2016</p>
 * @author Faton M. Berisha
 * @version 6.0.0
 */

package numeric;

import java.util.*;
import java.awt.Point;
import javax.swing.*;

/**
 * A demo view for equation solving iterative methods.
 */
public class EquationDemoView extends AbstractIterationTable implements
		Observer {

	private static final long serialVersionUID = 3;

	private int currentIteration = 0;

	private static Point frameLocation = new Point();
	private static int offset = 20;

	/**
	 * Constructs a demo view with title for equation solving iterative methods.
	 * 
	 * @param frameTitle
	 *            the title of the frame
	 * @param solver
	 *            the equation solver
	 */
	public EquationDemoView(String frameTitle, EquationSolver solver) {
		columnHeader = new String[2];
		columnHeader[0] = "k";
		columnHeader[1] = "p_k";
		data = new Object[solver.getNumIterations() + 1][2];

		JTable table = new JTable(this);
		JScrollPane sp = new JScrollPane(table);
		JFrame frame = new JFrame(frameTitle);
		frame.getContentPane().add(sp);
		frame.pack();
		frame.setLocation(frameLocation);
		frameLocation.translate(offset, offset);
		frame.setVisible(true);

		table.setDefaultRenderer(Double.class,
				new AbstractTable.DoubleRenderer());

		solver.addSolutionObserver(this);
	}

	/**
	 * Constructs a demo view for equation solving iterative methods.
	 * 
	 * @param solver
	 *            the equation solver
	 */
	public EquationDemoView(EquationSolver solver) {
		this("Tabela e iterimeve", solver);
	}

	public int getColumnCount() {
		return 2;
	}

	public int getRowCount() {
		return currentIteration;
	}

	public void update(Observable o, Object arg) {
		data[currentIteration][0] = new Integer(currentIteration);
		if (arg instanceof Matrix) {
			data[currentIteration][1] = ((Matrix) arg).get(0, 0);
		}
		fireTableDataChanged();
		currentIteration++;
	}

}
